# == Define: postfix::file_map
#
# This definition manages a file-defined Postfix map.
#
# === Parameters
#
# [*filename*]
#   The name of the data file. Defaults to $postfix_conf_dir/$title.
#
# [*source*]
#   The source URL for the file. Parameters *source* and *content* can't both
#   be defined at the same time.
#
# [*content*]
#   The contents of the file. Parameters *source* and *content* can't both
#   be defined at the same time.
#
# [*do_postmap*]
#   Whether or not to run the postmap command after creating or modifying the
#   file. Defaults to false.
#
# === Example
#
#   postfix::file_map { 'access':
#     source     => 'puppet:///modules/mail/postfix/access',
#     do_postmap => true,
#   }
#
define postfix::file_map (
  $filename   = undef,
  $source     = undef,
  $content    = undef,
  $do_postmap = false,
) {

  if (! $source) and (! $content) {
    fail('postfix::file_map requires either a source or a content.')
  }
  if $source and $content {
    fail('postfix::file_map cannot have both a source and a content.')
  }

  if $filename {
    $cfgfile = $filename
  } else {
    $cfgfile = "${postfix::postfix_conf_dir}/${title}"
  }

  file { $cfgfile:
    ensure  => present,
    owner   => 'root',
    group   => 'root',
    mode    => '0444',
    require => Class['postfix::install']
  }

  if $source {
    File[$cfgfile] { source => $source }
  }
  if $content {
    File[$cfgfile] { content => $content }
  }

  if $do_postmap {
    exec { "${postfix::postmap} ${cfgfile}":
      refreshonly => true,
      subscribe   => File[$cfgfile],
      notify      => Class['postfix::service'],
    }
  }

}
